@@ -6,7 +6,7 @@ IRI - Internationalized Resource Identifiers
 
 =head1 VERSION
 
-This document describes IRI version 0.001
+This document describes IRI version 0.003
 
 =head1 SYNOPSIS
 
@@ -31,6 +31,11 @@ serializing, and base resolution.
 
 =over 4
 
+=item C<< as_string >>
+
+Returns the absolute IRI string resolved against the base IRI, if present;
+the relative IRI string otherwise.
+
 =item C<< abs >>
 
 Returns the absolute IRI string (resolved against the base IRI if present).
@@ -53,18 +58,20 @@ Returns the respective component of the parsed IRI.
 
 =cut
 
-package IRI 0.001 {
+package IRI 0.003 {
 	use Moose;
 	use Moose::Util::TypeConstraints;
 	use v5.14;
 	use warnings;
 	
 	class_type 'URI';
+	coerce 'IRI' => from 'Str' => via { IRI->new( value => $_ ) };
 	coerce 'IRI' => from 'URI' => via { IRI->new( value => $_->as_string ) };
 
 	has 'value' => (is => 'ro', isa => 'Str', default => '');
 	has 'base' => (is => 'ro', isa => 'IRI', predicate => 'has_base', coerce => 1);
 	has 'components' => (is => 'ro', writer => '_set_components');
+	has 'as_string' => (is => 'ro', isa => 'Str', lazy => 1, builder => '_as_string');
 	has 'abs' => (is => 'ro', lazy => 1, builder => '_abs');
 	has 'resolved_components' => (
 		is		=> 'ro',
@@ -339,6 +346,15 @@ package IRI 0.001 {
 		return $value;
 	}
 
+	sub _as_string {
+		my $self	= shift;
+		if ($self->has_base) {
+			return $self->abs;
+		} else {
+			return $self->value;
+		}
+	}
+	
 	sub _string_from_components {
 		my $self		= shift;
 		my $components	= shift;
